# CRISPRbuilder_TB
------------------

>This **README.md** gives you the gist of the CRISPRbuilder_TB package. Please refer to **crisprbuilder_tb.md** included in the package for more detailed explanation.    


## Purpose of this package
--------------------------

>Collect and annotate Mycobacterium tuberculosis whole genome sequencing data for CRISPR investigation.    


## Requirements
---------------

>CRISPRbuilder_TB needs the following dependencies to work:

* python >= "3.6"
* xlrd >= "1.2.0"
* xmltodict >= "0.12.0"
* biopython >= "1.77"

>These different versions are automatically downloaded when installing the CRISPRbuilder_TB package.    


## Installation
---------------

>Install the package by writing in the command prompt: `pip3 install crisprbuilder_tb`.    


## How to use this package
--------------------------

>The most often common instruction for this package is: `python -m crisprbuilder_tb --collect {SRA_reference}`.

See the attached **criprbuilder-tb.md** for a comprehensive explanation.    


## History
----------

First version of this package, which is 1.0.0 was published on July 2020.
